@@ -10,6 +10,8 @@ from contracts_lib_py.conditions.access_proof import AccessProofCondition
 from contracts_lib_py.conditions.compute_execution import ComputeExecutionCondition
 from contracts_lib_py.conditions.condition_manager import ConditionStoreManager
 from contracts_lib_py.conditions.escrow_reward import EscrowPaymentCondition
+from contracts_lib_py.conditions.nft_escrow_reward import NFTEscrowPaymentCondition
+from contracts_lib_py.conditions.nft721_escrow_reward import NFT721EscrowPaymentCondition
 from contracts_lib_py.conditions.hash_lock import HashLockCondition
 from contracts_lib_py.conditions.lock_reward import LockPaymentCondition
 from contracts_lib_py.conditions.nft_access import NFTAccessCondition
@@ -19,13 +21,18 @@ from contracts_lib_py.conditions.sign import SignCondition
 from contracts_lib_py.conditions.threshold import ThresholdCondition
 from contracts_lib_py.conditions.transfer_did import TransferDIDOwnershipCondition
 from contracts_lib_py.conditions.transfer_nft import TransferNFTCondition
+from contracts_lib_py.conditions.transfer_nft721 import TransferNFT721Condition
 from contracts_lib_py.conditions.white_listing import WhitelistingCondition
 from contracts_lib_py.didregistry import DIDRegistry
 from contracts_lib_py.dispenser import Dispenser
 from contracts_lib_py.generic_contract import GenericContract, GenericContractExternal
 from contracts_lib_py.nft_upgradeable import NFTUpgradeable
+from contracts_lib_py.nft721_upgradeable import NFT721Upgradeable
 from contracts_lib_py.templates.access_template import AccessTemplate
 from contracts_lib_py.templates.access_proof_template import AccessProofTemplate
+from contracts_lib_py.templates.nft_access_proof_template import NFTAccessProofTemplate
+from contracts_lib_py.templates.nft_access_swap_template import NFTAccessSwapTemplate
+from contracts_lib_py.templates.nft_sales_with_access_template import NFTSalesWithAccessTemplate
 from contracts_lib_py.templates.compute_execution_template import EscrowComputeExecutionTemplate
 from contracts_lib_py.templates.did_sales_template import DIDSalesTemplate
 from contracts_lib_py.templates.nft_access_template import NFTAccessTemplate
@@ -52,6 +59,7 @@ class Keeper(object):
         77: 'POA_Sokol',
         99: 'POA_Core',
         137: 'matic',
+        1337: 'geth-localnet',
         8996: 'spree',
         8997: 'polygon-localnet',
         42220: 'celo',
@@ -98,7 +106,12 @@ class Keeper(object):
         self.dispenser = self._try_optional_contract(Dispenser)
         self.token = self._try_optional_contract(Token)
         self.nft_upgradeable = self._try_optional_contract(NFTUpgradeable)
-
+        self.nft721_upgradeable = self._try_optional_contract(NFT721Upgradeable)
+        self.nft_escrow_payment_condition = self._try_optional_contract(NFTEscrowPaymentCondition)
+        self.nft721_escrow_payment_condition = self._try_optional_contract(NFT721EscrowPaymentCondition)
+        self.nft_access_proof_template = self._try_optional_contract(NFTAccessProofTemplate)
+        self.nft_access_swap_template = self._try_optional_contract(NFTAccessSwapTemplate)
+        self.nft_sales_with_access_template = self._try_optional_contract(NFTSalesWithAccessTemplate)
 
         # required contracts
         self.did_registry = DIDRegistry.get_instance()
@@ -119,10 +132,16 @@ class Keeper(object):
         self.nft_holder_condition = NFTHolderCondition.get_instance()
         self.nft_lock_condition = NFTLockCondition.get_instance()
         self.transfer_nft_condition = TransferNFTCondition.get_instance()
+        self.transfer_nft721_condition = TransferNFT721Condition.get_instance()
         self.transfer_did_condition = TransferDIDOwnershipCondition.get_instance()
         self.nft_access_template = NFTAccessTemplate.get_instance()
         self.did_sales_template = DIDSalesTemplate.get_instance()
         self.nft_sales_template = NFTSalesTemplate.get_instance()
+        templates = {}
+        for i in [self.access_template, self.nft_access_template, self.nft_access_proof_template, self.nft_access_swap_template,self.nft_sales_with_access_template, self.did_sales_template, self.nft_sales_template, self.access_proof_template, self.escrow_compute_execution_template]:
+            if i != None:
+                templates[i.address] = i
+        self.agreement_manager.set_templates(templates)
         contracts = [
             self.token,
             self.did_registry,
@@ -135,6 +154,8 @@ class Keeper(object):
             self.sign_condition,
             self.lock_payment_condition,
             self.escrow_payment_condition,
+            self.nft_escrow_payment_condition,
+            self.nft721_escrow_payment_condition,
             self.access_condition,
             self.access_proof_condition,
             self.nft_access_condition,
@@ -145,9 +166,13 @@ class Keeper(object):
             self.nft_holder_condition,
             self.nft_lock_condition,
             self.transfer_nft_condition,
+            self.transfer_nft721_condition,
             self.transfer_did_condition,
             self.nft_access_template,
             self.did_sales_template,
+            self.nft_access_proof_template,
+            self.nft_access_swap_template,
+            self.nft_sales_with_access_template,
             self.nft_sales_template
         ]
         if self.dispenser:
