@@ -9,9 +9,10 @@ from web3 import Web3
 from contracts_lib_py import Keeper
 from contracts_lib_py.contract_handler import ContractHandler
 from contracts_lib_py.didregistry import DIDRegistry
-from contracts_lib_py.web3_provider import Web3Provider
-from tests.resources.helper_functions import get_consumer_account, get_keeper_url, get_publisher_account
+from contracts_lib_py.nft_upgradeable import NFTUpgradeable
+from tests.resources.helper_functions import get_consumer_account, get_publisher_account
 
+ZERO_ADDRESS = '0x0000000000000000000000000000000000000000'
 
 def new_did():
     return uuid.uuid4().hex + uuid.uuid4().hex
@@ -165,10 +166,7 @@ def test_grant_permissions():
 
     assert not did_registry.get_permission(asset_id, test_address)
 
-@pytest.mark.xfail(
-    Web3Provider.get_web3(get_keeper_url()).net.version == '8997',
-    reason = "API not available on polygon"
-)
+
 def test_provenance_events():
     register_account = get_publisher_account()
     did_registry = DIDRegistry.get_instance()
@@ -254,10 +252,7 @@ def test_delegate_provenance():
     assert did_registry.is_provenance_delegate(Web3.toBytes(hexstr=asset_id),
                                                delegated_account.address) is False
 
-@pytest.mark.xfail(
-    Web3Provider.get_web3(get_keeper_url()).net.version == '8997',
-    reason = "API not available on polygon"
-)
+
 def test_search_multiple_provenance_event_tests():
     register_account = get_publisher_account()
     did_registry = DIDRegistry.get_instance()
@@ -324,9 +319,9 @@ def test_royalties_are_valid():
 
     did_registry.transfer_did_ownership(asset_id, new_owner_address, register_account)
 
-    assert did_registry.are_royalties_valid(asset_id, [80, 20], [someone_address, register_account.address]) is True
-    assert did_registry.are_royalties_valid(asset_id, [90], [someone_address]) is False
-    assert did_registry.are_royalties_valid(asset_id, [90, 10], [someone_address, register_account.address]) is False
+    assert did_registry.are_royalties_valid(asset_id, [80, 20], [someone_address, register_account.address], ZERO_ADDRESS) is True
+    assert did_registry.are_royalties_valid(asset_id, [90], [someone_address], ZERO_ADDRESS) is False
+    assert did_registry.are_royalties_valid(asset_id, [90, 10], [someone_address, register_account.address], ZERO_ADDRESS) is False
 
 
 def test_get_did():
@@ -361,6 +356,7 @@ def test_get_did():
 def test_nft():
     register_account = get_publisher_account()
     did_registry = DIDRegistry.get_instance()
+    nft_upgradeable = NFTUpgradeable.get_instance()
     w3 = Web3
 
     did_seed = new_did()
@@ -377,18 +373,18 @@ def test_nft():
     assert did_registry.register_mintable_did(did_seed, checksum_test, url, cap, royalties, account=register_account,
                                               providers=[test_address], activity_id=activity_id) is True
 
-    balance = did_registry.balance(register_account.address, asset_id)
+    balance = nft_upgradeable.balance(register_account.address, asset_id)
     assert balance == 0
-    balance_consumer = did_registry.balance(someone_address, asset_id)
+    balance_consumer = nft_upgradeable.balance(someone_address, asset_id)
     assert balance_consumer == 0
 
     did_registry.mint(asset_id, 10, account=register_account)
-    assert balance + 10 == did_registry.balance(register_account.address, asset_id)
-    assert did_registry.transfer_nft(asset_id, someone_address, 1, register_account)
-    assert did_registry.balance(register_account.address, asset_id) == 9
-    assert did_registry.balance(someone_address, asset_id) == balance_consumer + 1
+    assert balance + 10 == nft_upgradeable.balance(register_account.address, asset_id)
+    assert nft_upgradeable.transfer_nft(asset_id, someone_address, 1, register_account)
+    assert nft_upgradeable.balance(register_account.address, asset_id) == 9
+    assert nft_upgradeable.balance(someone_address, asset_id) == balance_consumer + 1
     did_registry.burn(asset_id, 9, account=register_account)
-    assert balance == did_registry.balance(register_account.address, asset_id)
+    assert balance == nft_upgradeable.balance(register_account.address, asset_id)
 
 
 def test_nft_approval():
